@@ -1,4 +1,4 @@
-from .isa import isa, issubclass, assert_isa, PythonTyping, TypeMistmatchError
+from .isa import isa, issubclass, assert_isa, PythonTyping, TypeMismatchError
 from .dispatch import MultiDispatch, DispatchError
 from .dataclass import dataclass
 
@@ -8,4 +8,4 @@ def Dispatch(typesystem=PythonTyping()):
 
 
 
-__version__ = "0.1.5"
+__version__ = "0.1.16"
